
library(binequality)

library(readxl)
income_2018 <- read_excel("income_2018.xlsx")

income_2018<-as.data.frame(income_2018)
income_2018[42,"high"]<-Inf
income_2018$high<-as.numeric(income_2018$high)

n <- nrow(income_2018)
fit_LN <- fitFunc(ID=rep("US",n), 
                  hb=income_2018[,"number"], 
                  bin_min=income_2018[,"low"], 
                  bin_max=income_2018[,"high"],
                  obs_mean=income_2018[,"mean"], 
                  ID_name="Country")

N=income_2018$number
y2=N/sum(N)/diff(income_2018$low) 
u=seq(min(income_2018$low),
         max(income_2018$low),length=101)
v=dlnorm(u,fit_LN$parameters[1],
            fit_LN$parameters[2])
plot(u,v,col="blue",type="l",lwd=2,xlab="income",ylab="density",main="Income distribution in US in 2018")
for(i in 1:(n-1)) rect(income_2018$low[i],0,
                          income_2018$high[i],y2[i],col=rgb(0,0,0,.2),
                         border="white")


 N <- income_2018$number
 y1 <- cumsum(N)/sum(N) 
u <- seq(min(income_2018$low),
           max(income_2018$low),length=101) 
v <- plnorm(u,fit_LN$parameters[1],fit_LN$parameters[2])
plot(u,v,col="blue",type="l",lwd=2)
for(i in 1:(n-1)) rect(income_2018$low[i],0,
                          income_2018$high[i], y1[i],col=rgb(0,0,0,.2))
for(i in 1:(n-1)) rect(income_2018$low[i],
                         y1[i],income_2018$high[i],c(0,y1)[i],
                          col=rgb(0,0,0,.4))


fits=run_GB_family(ID=rep("US",n),
                    hb=income_2018[,"number"],
                    bin_min=income_2018[,"low"],
                    bin_max=income_2018[,"high"],
                    obs_mean=income_2018[,"mean"],
                    ID_name="Country")

wyniki<-fits$fit.filter[,c("gini","aic","bic")]

rownames(wyniki)<-c("GB2", "GG", 
                "BETA2", "DAGUM", "SINGMAD", "LOGNO", 
                "WEI", "GA", "LOGLOG", "PARETO2")
library(xtable)
xtable(wyniki,digits=4)

wyniki2<-fits$params
wyniki2<-Reduce(rbind,wyniki2)
rownames(wyniki2)<-rownames(wyniki)
xtable(wyniki2,digits=4)

income_2010 <- read_excel("income_2010.xlsx")


income_2010<-as.data.frame(income_2010)
income_2010[42,"high"]<-Inf
income_2010$high<-as.numeric(income_2010$high)

n <- nrow(income_2010)
fit_LN <- fitFunc(ID=rep("US",n), 
                  hb=income_2010[,"number"], 
                  bin_min=income_2010[,"low"], 
                  bin_max=income_2010[,"high"],
                  obs_mean=income_2010[,"mean"], 
                  ID_name="Country")

N=income_2010$number
y2=N/sum(N)/diff(income_2010$low) 
u=seq(min(income_2010$low),
      max(income_2010$low),length=101)
v=dlnorm(u,fit_LN$parameters[1],
         fit_LN$parameters[2])
plot(u,v,col="blue",type="l",lwd=2,xlab="income",ylab="density",main="Income distribution in US in 2010")
for(i in 1:(n-1)) rect(income_2010$low[i],0,
                       income_2010$high[i],y2[i],col=rgb(0,0,0,.2),
                       border="white")


N <- income_2010$number
y1 <- cumsum(N)/sum(N) 
u <- seq(min(income_2010$low),
         max(income_2010$low),length=101) 
v <- plnorm(u,fit_LN$parameters[1],fit_LN$parameters[2])
plot(u,v,col="blue",type="l",lwd=2)
for(i in 1:(n-1)) rect(income_2010$low[i],0,
                       income_2010$high[i], y1[i],col=rgb(0,0,0,.2))
for(i in 1:(n-1)) rect(income_2010$low[i],
                       y1[i],income_2010$high[i],c(0,y1)[i],
                       col=rgb(0,0,0,.4))


fits=run_GB_family(ID=rep("US",n),
                   hb=income_2010[,"number"],
                   bin_min=income_2010[,"low"],
                   bin_max=income_2010[,"high"],
                   obs_mean=income_2010[,"mean"],
                   ID_name="Country")

wyniki<-fits$fit.filter[,c("gini","aic","bic")]

rownames(wyniki)<-c("GB2", "GG", 
                    "BETA2", "DAGUM", "SINGMAD", "LOGNO", 
                    "WEI", "GA", "LOGLOG", "PARETO2")

xtable(wyniki,digits=4)

wyniki2<-fits$params
wyniki2<-Reduce(rbind,wyniki2)
rownames(wyniki2)<-rownames(wyniki)
xtable(wyniki2,digits=4)
