import java.awt.geom.Point2D;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.PrintStream;
import java.util.Locale;
import java.util.zip.GZIPInputStream;

import statistics.Histogram;
import statistics.LogHistogram;

public class Convert {
	static double MIN = Double.POSITIVE_INFINITY;
	static double MAX = Double.NEGATIVE_INFINITY;
	
	public static void toList(String sIn, String sOut) throws IOException, ClassNotFoundException{
		ObjectInputStream ois = new ObjectInputStream(new GZIPInputStream(new FileInputStream(sIn)));
		Society soc = (Society) ois.readObject();
		ois.close();
		PrintStream ps = new PrintStream(sOut);
		if (MIN==Double.POSITIVE_INFINITY)
			MIN = soc.agents[soc.getPoorestAgentIndex()].wealth;
		if (MAX==Double.NEGATIVE_INFINITY)
			MAX = soc.agents[soc.getRichiestAgentIndex()].wealth;
		Histogram hist = new Histogram(MIN, MAX, 100);
		int i = (int) -Math.log10(MIN) + 2;	
		String sWealthFormat = "%." + i + "f";
		String sAgentFormat  = "%." + ((int)Math.log10(soc.agents.length) + 2) + "f";
		for(i=0; i<soc.agents.length; i++){
			hist.add(soc.agents[i].wealth);
		}
		Point2D[] points = hist.getAsPoints();
		for(i=0; i<points.length; i++) {
			ps.printf(Locale.US, sWealthFormat + "\t" + sAgentFormat + "\n", points[i].getX(), points[i].getY());
		}
		ps.close();
	}
	
	
	public static void main(String[] args) throws ClassNotFoundException, IOException{
		if (args.length==0) {
			System.out.println("Usage: java -cp trading.jar Convert file1 file2 ...");
			System.out.println("where files stores a binary snapshot of population and as a result file.txt is produced with histogram in CSV format");
			
		}
		for(String s: args) {
			toList(s, s+".txt");
		}
/*
		toList("delta/snapshot-3-0.dat.gz", "delta/snapshot-3-0.txt");
		toList("delta/snapshot-3-10.dat.gz", "delta/snapshot-3-10.txt");
		toList("delta/snapshot-3-100.dat.gz", "delta/snapshot-3-100.txt");
		toList("delta/snapshot-3-1000.dat.gz", "delta/snapshot-3-1000.txt");
		toList("delta/snapshot-4-0.dat.gz", "delta/snapshot-4-0.txt");
		toList("delta/snapshot-4-10.dat.gz", "delta/snapshot-4-10.txt");
		toList("delta/snapshot-4-100.dat.gz", "delta/snapshot-4-100.txt");
		toList("delta/snapshot-4-1000.dat.gz", "delta/snapshot-4-1000.txt");
		
		toList("delta/snapshot-5-1000.dat.gz", "delta/snapshot-5-1000.txt");
		toList("delta/snapshot-5-100.dat.gz", "delta/snapshot-5-100.txt");
		toList("delta/snapshot-5-10.dat.gz", "delta/snapshot-5-10.txt");
		toList("delta/snapshot-5-0.dat.gz", "delta/snapshot-5-0.txt");
		
		toList("delta/snapshot-6-0.dat.gz", "delta/snapshot-6-0.txt");
		toList("delta/snapshot-6-10.dat.gz", "delta/snapshot-6-10.txt");
		toList("delta/snapshot-6-100.dat.gz", "delta/snapshot-6-100.txt");
		toList("delta/snapshot-6-1000.dat.gz", "delta/snapshot-6-1000.txt");
		toList("delta/snapshot-7-0.dat.gz", "delta/snapshot-7-0.txt");
		toList("delta/snapshot-7-10.dat.gz", "delta/snapshot-7-10.txt");
		toList("delta/snapshot-7-100.dat.gz", "delta/snapshot-7-100.txt");
		toList("delta/snapshot-7-1000.dat.gz", "delta/snapshot-7-1000.txt");

		toList("uniform/snapshot-5-1000.dat.gz", "uniform/snapshot-5-1000.txt");
		toList("uniform/snapshot-5-100.dat.gz", "uniform/snapshot-5-100.txt");
		toList("uniform/snapshot-5-10.dat.gz", "uniform/snapshot-5-10.txt");
		toList("uniform/snapshot-5-0.dat.gz", "uniform/snapshot-5-0.txt");

		toList("gaussian/snapshot-5-1000.dat.gz", "gaussian/snapshot-5-1000.txt");
		toList("gaussian/snapshot-5-100.dat.gz", "gaussian/snapshot-5-100.txt");
		toList("gaussian/snapshot-5-10.dat.gz", "gaussian/snapshot-5-10.txt");
		toList("gaussian/snapshot-5-0.dat.gz", "gaussian/snapshot-5-0.txt");

		toList("cauchy/snapshot-5-1000.dat.gz", "cauchy/snapshot-5-1000.txt");
		toList("cauchy/snapshot-5-100.dat.gz", "cauchy/snapshot-5-100.txt");
		toList("cauchy/snapshot-5-10.dat.gz", "cauchy/snapshot-5-10.txt");
		toList("cauchy/snapshot-5-0.dat.gz", "cauchy/snapshot-5-0.txt");

		toList("exponential/snapshot-5-1000.dat.gz", "exponential/snapshot-5-1000.txt");
		toList("exponential/snapshot-5-100.dat.gz", "exponential/snapshot-5-100.txt");
		toList("exponential/snapshot-5-10.dat.gz", "exponential/snapshot-5-10.txt");
		toList("exponential/snapshot-5-0.dat.gz", "exponential/snapshot-5-0.txt");

		toList("richpoor/snapshot-5-1000.dat.gz", "richpoor/snapshot-5-1000.txt");
		toList("richpoor/snapshot-5-100.dat.gz", "richpoor/snapshot-5-100.txt");
		toList("richpoor/snapshot-5-10.dat.gz", "richpoor/snapshot-5-10.txt");
		toList("richpoor/snapshot-5-0.dat.gz", "richpoor/snapshot-5-0.txt");
*/
/*
		toList("delta/min/snapshot-5-1000.dat.gz", "delta/min/snapshot-5-1000.txt");
		toList("delta/min/snapshot-5-500.dat.gz", "delta/min/snapshot-5-500.txt");
		toList("delta/min/snapshot-5-200.dat.gz", "delta/min/snapshot-5-200.txt");
		toList("delta/min/snapshot-5-100.dat.gz", "delta/min/snapshot-5-100.txt");
		toList("delta/min/snapshot-5-50.dat.gz", "delta/min/snapshot-5-50.txt");
		toList("delta/min/snapshot-5-20.dat.gz", "delta/min/snapshot-5-20.txt");
		toList("delta/min/snapshot-5-10.dat.gz", "delta/min/snapshot-5-10.txt");

		toList("delta/ave/snapshot-5-1000.dat.gz", "delta/ave/snapshot-5-1000.txt");
		toList("delta/ave/snapshot-5-500.dat.gz", "delta/ave/snapshot-5-500.txt");
		toList("delta/ave/snapshot-5-200.dat.gz", "delta/ave/snapshot-5-200.txt");
		toList("delta/ave/snapshot-5-100.dat.gz", "delta/ave/snapshot-5-100.txt");
		toList("delta/ave/snapshot-5-50.dat.gz", "delta/ave/snapshot-5-50.txt");
		toList("delta/ave/snapshot-5-20.dat.gz", "delta/ave/snapshot-5-20.txt");
		toList("delta/ave/snapshot-5-10.dat.gz", "delta/ave/snapshot-5-10.txt");

		toList("delta/geo/snapshot-5-1000.dat.gz", "delta/geo/snapshot-5-1000.txt");
		toList("delta/geo/snapshot-5-500.dat.gz", "delta/geo/snapshot-5-500.txt");
		toList("delta/geo/snapshot-5-200.dat.gz", "delta/geo/snapshot-5-200.txt");
		toList("delta/geo/snapshot-5-100.dat.gz", "delta/geo/snapshot-5-100.txt");
		toList("delta/geo/snapshot-5-50.dat.gz", "delta/geo/snapshot-5-50.txt");
		toList("delta/geo/snapshot-5-20.dat.gz", "delta/geo/snapshot-5-20.txt");
		toList("delta/geo/snapshot-5-10.dat.gz", "delta/geo/snapshot-5-10.txt");
*/	
	}
	
/*
	public static void main(String[] args) throws FileNotFoundException,
			IOException, ClassNotFoundException {
		Pattern p = Pattern.compile("[0-9]+");
		File dir = new File(".");
		File[] fa = dir.listFiles();
		for(File f: fa){
			if (!f.getName().startsWith("snapshot-"))
				continue;
			Matcher m = p.matcher(f.getName());
			if (!m.find())
				continue;
			String sNumber = m.group();
			ObjectInputStream ois = new ObjectInputStream(new GZIPInputStream(new FileInputStream(f)));
			Society ind = (Society) ois.readObject();
//			LogHistogram h = ind.toLogHistogram();
			Histogram h = ind.toHistogram(false);
			Point2D[] pa = h.getAsPoints(false);
			PrintStream ps = new PrintStream("loghist-" + sNumber + ".txt");
			for (int j = 0; j < pa.length; j++) {
				ps.printf(Locale.US, "%e\t%e\n", pa[j].getX(),
						pa[j].getY());
			}
			ps.close();
			System.out.printf(Locale.US, "%s\t%f\t%f\t%f\t%f\n", sNumber, ind.getTotal(), ind.getFractionHaving(0.95), ind.getFractionHaving(0.9), ind.getFractionHaving(0.8));
			ois.close();
		}
	}
*/	
}
