import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.ObjectOutputStream;
import java.util.Locale;
import java.util.Properties;
import java.util.zip.GZIPOutputStream;


public class Main {
	
	private static int N;
	private static int CYCLES;

	static{
		Properties p = new Properties();
			try {
				p.load(new FileInputStream("input.txt"));
				N = Integer.parseInt(p.getProperty("N", "100000"));
				CYCLES = Integer.parseInt(p.getProperty("Cycles", "5000"));
			} catch (IOException e) {
				e.printStackTrace();
			}
	}
	
	public static void main(String[] args) throws FileNotFoundException, IOException{		
		System.out.println("The evolution is governed by the rules in the input.txt file located in current directory. Please read example input file for more informations. If there is no input.txt file, default parameters are used");
		System.out.println("Snapshot of population are stored in a binary format, which can be converted by Convert class to the CSV histograms");
		System.out.println("On the output the program prints: cycle no, wealth factor, no of wealthest agent, asset of wealthiest agent, median asset, fraction having 0.9 of the total wealth, Gini index, Shanon entropy");
		Society ind = new Society(N);
		ind.init();
		
		for(int i=0; i<=CYCLES+1; i++){
			ind.normalize();
			if (i==0 || i==10 || i==20 || i==50 || i==100 || i==200 || i==500 || i==1000 || i%1000==0){
				ObjectOutputStream oos = new ObjectOutputStream(new GZIPOutputStream(new FileOutputStream("snapshot-"+((int)Math.log10(N))+"-" + i+".dat.gz")));
				oos.writeObject(ind);
				oos.close();
			}
			//if (i%5==0){
				int index = ind.getRichiestAgentIndex();
//				System.out.printf(Locale.US, "%d\t%f\t%f\t%e\t%e\t%e\t%d\t%d\t%f\t%f\t%f\t%f\n", i, ind.gain, ind.getWealth(index), ind.quantiles[1], ind.quantiles[5], ind.quantiles[8], index, ind.active,ind.getFractionHaving(0.99), ind.getFractionHaving(0.9), ind.getFractionHaving(), ind.getGiniCoefficient());
				System.out.printf(Locale.US, "%d\t%f\t%d\t%.8f\t%e\t%f\t%f\t%f\n", i, ind.gain, index, ind.getWealth(index), ind.quantiles[5], ind.getFractionHaving(0.9), ind.getGiniCoefficient(), ind.getEntropy());
			//}
			ind.doCycle();
		}
	}
}
